@@ -2,8 +2,8 @@ from typing import Optional
 from dataclasses import dataclass, field
 
 from energytt_platform.serialize import Serializable
+from energytt_platform.models.tech import Technology
 
-from .technologies import Technology
 from .common import EnergyDirection, Address
 
 
@@ -13,10 +13,20 @@ MeteringPointType = EnergyDirection
 @dataclass
 class MeteringPoint(Serializable):
     """
-    A single Metering Point.
+    TODO
     """
     gsrn: str
-    sector: str
     type: Optional[MeteringPointType] = field(default=None)
+    sector: Optional[str] = field(default=None)
     technology: Optional[Technology] = field(default=None)
     address: Optional[Address] = field(default=None)
+
+
+@dataclass
+class MeteringPointDelegate(Serializable):
+    """
+    An actor (identified by its subject) who has been delegated
+    access to a MeteringPoint (identified by its GSRN number).
+    """
+    gsrn: str
+    subject: str
